#!/bin/sh

set -u

mkdir -p /data/acme
chmod 700 /data/acme
for IDX in $(printenv | grep -E '^ACME_\d+_EMAIL=' | sed -E 's/ACME_(\d+)_EMAIL.*/\1/'); do
  for CA in $(vault kv list -format json ${ACME_KV_ACCOUNT_ROOT} | jq -r ".[]"); do
    CA_FQDN=$(echo -n ${CA} | sed -E 's|^(https?://)?([^/]+).*|\2|')
    for EMAIL in $(vault kv list -format json ${ACME_KV_ACCOUNT_ROOT}/${CA_FQDN} | jq -r ".[]"); do
      echo "Restoring ACME account ${EMAIL} for ${CA_FQDN}"
      mkdir -p /data/acme/accounts/${CA_FQDN}/${EMAIL}/keys
      vault kv get -field metadata ${ACME_KV_ACCOUNT_ROOT}/${CA_FQDN}/${EMAIL} > /data/acme/accounts/${CA_FQDN}/${EMAIL}/account.json
      vault kv get -field key ${ACME_KV_ACCOUNT_ROOT}/${CA_FQDN}/${EMAIL} > /data/acme/accounts/${CA_FQDN}/${EMAIL}/keys/${EMAIL}.key
    done
  done
  
  KV_CERT_ROOT=$(printenv ACME_${IDX}_KV_CERT_ROOT)
  mkdir -p /data/acme/certificates
  for CERT in $(vault kv list -format json ${KV_CERT_ROOT} | jq -r ".[]"); do
    echo "Restoring cert ${CERT} to /data/acme/certificates/"
    vault kv get -field cert ${KV_CERT_ROOT}/${CERT} > /data/acme/certificates/${CERT}.crt
    vault kv get -field key ${KV_CERT_ROOT}/${CERT} > /data/acme/certificates/${CERT}.key
    vault kv get -field metadata ${KV_CERT_ROOT}/${CERT} > /data/acme/certificates/${CERT}.json
    vault kv get -field issuer ${KV_CERT_ROOT}/${CERT} > /data/acme/certificates/${CERT}.issuer.crt
  done
done

exit 0
